@@ -2,7 +2,7 @@
 #' @param height a vector of height profile
 #'
 
-hgt.to.dpt<-function(height){
-  depth<-max(height)-height
+hgt_to_dpt <- function(height){
+  depth <- max(height) - height
   return(depth)
 }
